@@ -28,10 +28,12 @@ NAVIGATION_BROWSE = ["navigationEndpoint", "browseEndpoint"]
 NAVIGATION_BROWSE_ID = [*NAVIGATION_BROWSE, "browseId"]
 PAGE_TYPE = ["browseEndpointContextSupportedConfigs", "browseEndpointContextMusicConfig", "pageType"]
 WATCH_VIDEO_ID = ["watchEndpoint", "videoId"]
+PLAYLIST_ID = ["playlistId"]
+WATCH_PLAYLIST_ID = ["watchEndpoint", *PLAYLIST_ID]
 NAVIGATION_VIDEO_ID = ["navigationEndpoint", *WATCH_VIDEO_ID]
 QUEUE_VIDEO_ID = ["queueAddEndpoint", "queueTarget", "videoId"]
-NAVIGATION_PLAYLIST_ID = ["navigationEndpoint", "watchEndpoint", "playlistId"]
-WATCH_PID = ["watchPlaylistEndpoint", "playlistId"]
+NAVIGATION_PLAYLIST_ID = ["navigationEndpoint", *WATCH_PLAYLIST_ID]
+WATCH_PID = ["watchPlaylistEndpoint", *PLAYLIST_ID]
 NAVIGATION_WATCH_PLAYLIST_ID = ["navigationEndpoint", *WATCH_PID]
 NAVIGATION_VIDEO_TYPE = [
     "watchEndpoint",
@@ -71,16 +73,19 @@ TASTE_PROFILE_ARTIST = ["title", "runs"]
 SECTION_LIST_CONTINUATION = ["continuationContents", "sectionListContinuation"]
 MENU_PLAYLIST_ID = [*MENU_ITEMS, 0, MNIR, *NAVIGATION_WATCH_PLAYLIST_ID]
 MULTI_SELECT = ["musicMultiSelectMenuItemRenderer"]
-HEADER_DETAIL = ["header", "musicDetailHeaderRenderer"]
-HEADER_SIDE = ["header", "musicSideAlignedItemRenderer"]
-HEADER_MUSIC_VISUAL = ["header", "musicVisualHeaderRenderer"]
+HEADER = ["header"]
+HEADER_DETAIL = [*HEADER, "musicDetailHeaderRenderer"]
+EDITABLE_PLAYLIST_DETAIL_HEADER = ["musicEditablePlaylistDetailHeaderRenderer"]
+HEADER_EDITABLE_DETAIL = [*HEADER, *EDITABLE_PLAYLIST_DETAIL_HEADER]
+HEADER_SIDE = [*HEADER, "musicSideAlignedItemRenderer"]
+HEADER_MUSIC_VISUAL = [*HEADER, "musicVisualHeaderRenderer"]
 DESCRIPTION_SHELF = ["musicDescriptionShelfRenderer"]
 DESCRIPTION = ["description", *RUN_TEXT]
 CAROUSEL = ["musicCarouselShelfRenderer"]
 IMMERSIVE_CAROUSEL = ["musicImmersiveCarouselShelfRenderer"]
 CAROUSEL_CONTENTS = [*CAROUSEL, "contents"]
-CAROUSEL_TITLE = ["header", "musicCarouselShelfBasicHeaderRenderer", *TITLE]
-CARD_SHELF_TITLE = ["header", "musicCardShelfHeaderBasicRenderer", *TITLE_TEXT]
+CAROUSEL_TITLE = [*HEADER, "musicCarouselShelfBasicHeaderRenderer", *TITLE]
+CARD_SHELF_TITLE = [*HEADER, "musicCardShelfHeaderBasicRenderer", *TITLE_TEXT]
 FRAMEWORK_MUTATIONS = ["frameworkUpdates", "entityBatchUpdate", "mutations"]
 
 
